CodeGen

Struct CodeGen 

pub struct CodeGen { /* private fields */ }
Available on crate feature lang only.
A builder to config and generate rust source code.

Implementations

Source

impl CodeGen

pub fn with_serde(self, on: bool) -> Self

Reset serde module generation flag, the default value is true.

pub fn target(self, path: impl AsRef<Path>) -> Self

Reset the target path of the code generation, the default value is current directory.

pub fn codegen(self, stats: impl AsRef<[Stat]>) -> Result<()>

invoke real rust code generation processing.